@@ -45,8 +45,10 @@ extern void register_builtin_render();
 extern void register_builtin_import();
 extern void register_builtin_projection();
 extern void register_builtin_cgaladv();
+extern void register_builtin_offset();
 extern void register_builtin_dxf_linear_extrude();
 extern void register_builtin_dxf_rotate_extrude();
+extern void register_builtin_text();
 extern void initialize_builtin_dxf_dim();
 
 /*!
@@ -70,14 +72,17 @@ void Builtins::initialize()
 	register_builtin_import();
 	register_builtin_projection();
 	register_builtin_cgaladv();
+	register_builtin_offset();
 	register_builtin_dxf_linear_extrude();
 	register_builtin_dxf_rotate_extrude();
+	register_builtin_text();
 
-	this->deprecations["dxf_linear_extrude"] = "linear_extrude";
-	this->deprecations["dxf_rotate_extrude"] = "rotate_extrude";
-	this->deprecations["import_stl"] = "import";
-	this->deprecations["import_dxf"] = "import";
-	this->deprecations["import_off"] = "import";
+	this->deprecations["dxf_linear_extrude"] = "linear_extrude()";
+	this->deprecations["dxf_rotate_extrude"] = "rotate_extrude()";
+	this->deprecations["import_stl"] = "import()";
+	this->deprecations["import_dxf"] = "import()";
+	this->deprecations["import_off"] = "import()";
+	this->deprecations["assign"] = "a regular assignment";
 }
 
 std::string Builtins::isDeprecated(const std::string &name)
@@ -90,18 +95,19 @@ std::string Builtins::isDeprecated(const std::string &name)
 
 Builtins::Builtins()
 {
-	this->globalscope.assignments.push_back(Assignment("$fn", new Expression(Value(0.0))));
-	this->globalscope.assignments.push_back(Assignment("$fs", new Expression(Value(2.0))));
-	this->globalscope.assignments.push_back(Assignment("$fa", new Expression(Value(12.0))));
-	this->globalscope.assignments.push_back(Assignment("$t", new Expression(Value(0.0))));
+	this->globalscope.assignments.push_back(Assignment("$fn", boost::shared_ptr<Expression>(new ExpressionConst(ValuePtr(0.0)))));
+	this->globalscope.assignments.push_back(Assignment("$fs", boost::shared_ptr<Expression>(new ExpressionConst(ValuePtr(2.0)))));
+	this->globalscope.assignments.push_back(Assignment("$fa", boost::shared_ptr<Expression>(new ExpressionConst(ValuePtr(12.0)))));
+	this->globalscope.assignments.push_back(Assignment("$t", boost::shared_ptr<Expression>(new ExpressionConst(ValuePtr(0.0)))));
 
 	Value::VectorType zero3;
-	zero3.push_back(Value(0.0));
-	zero3.push_back(Value(0.0));
-	zero3.push_back(Value(0.0));
-	Value zero3val(zero3);
-	this->globalscope.assignments.push_back(Assignment("$vpt", new Expression(zero3val)));
-	this->globalscope.assignments.push_back(Assignment("$vpr", new Expression(zero3val)));
+	zero3.push_back(ValuePtr(0.0));
+	zero3.push_back(ValuePtr(0.0));
+	zero3.push_back(ValuePtr(0.0));
+	ValuePtr zero3val(zero3);
+	this->globalscope.assignments.push_back(Assignment("$vpt", boost::shared_ptr<Expression>(new ExpressionConst(zero3val))));
+	this->globalscope.assignments.push_back(Assignment("$vpr", boost::shared_ptr<Expression>(new ExpressionConst(zero3val))));
+	this->globalscope.assignments.push_back(Assignment("$vpd", boost::shared_ptr<Expression>(new ExpressionConst(ValuePtr(500)))));
 }
 
 Builtins::~Builtins()
