@@ -9,7 +9,7 @@ namespace fs = boost::filesystem;
 
 std::vector<std::string> librarypath;
 
-void add_librarydir(const std::string &libdir)
+static void add_librarydir(const std::string &libdir)
 {
 	librarypath.push_back(libdir);
 }
@@ -77,10 +77,11 @@ fs::path find_valid_path(const fs::path &sourcepath,
 												 const std::vector<std::string> *openfilenames)
 {
 	if (boosty::is_absolute(localpath)) {
-		if (check_valid(localpath, openfilenames)) return boosty::absolute(localpath);
+		if (check_valid(localpath, openfilenames)) return boosty::canonical(localpath);
 	}
 	else {
 		fs::path fpath = sourcepath / localpath;
+		if (fs::exists(fpath)) fpath = boosty::canonical(fpath);
 		if (check_valid(fpath, openfilenames)) return fpath;
 		fpath = search_libs(localpath);
 		if (!fpath.empty() && check_valid(fpath, openfilenames)) return fpath;
@@ -88,7 +89,7 @@ fs::path find_valid_path(const fs::path &sourcepath,
 	return fs::path();
 }
 
-void parser_init(const std::string &applicationpath)
+void parser_init()
 {
 	// Add paths from OPENSCADPATH before adding built-in paths
 	const char *openscadpaths = getenv("OPENSCADPATH");
@@ -101,37 +102,9 @@ void parser_init(const std::string &applicationpath)
 		}
 	}
 
-	// This is the built-in user-writable library path
 #ifndef OPENSCAD_TESTING
-  // This will resolve to ~/Documents on Mac, "My Documents" on Windows and
-  // ~/.local/share on Linux
-	fs::path docdir(PlatformUtils::documentsPath());
-	add_librarydir(boosty::stringy(docdir / "OpenSCAD" / "libraries"));
+	add_librarydir(PlatformUtils::userLibraryPath());
 #endif
 
-	// This is the built-in read-only library path
-	std::string librarydir;
-	fs::path libdir(applicationpath);
-	fs::path tmpdir;
-#ifdef __APPLE__
-	// Libraries can be bundled on Mac. If not, fall back to development layout
-	bool isbundle = is_directory(libdir / ".." / "Resources");
-	if (isbundle) {
-		libdir /= "../Resources";
-		if (!is_directory(libdir / "libraries")) libdir /= "../../..";
-	}
-#elif !defined(WIN32)
-	if (is_directory(tmpdir = libdir / "../share/openscad/libraries")) {
-		librarydir = boosty::stringy(tmpdir);
-	} else if (is_directory(tmpdir = libdir / "../../share/openscad/libraries")) {
-		librarydir = boosty::stringy(tmpdir);
-	} else if (is_directory(tmpdir = libdir / "../../libraries")) {
-		librarydir = boosty::stringy(tmpdir);
-	} else
-#endif
-		if (is_directory(tmpdir = libdir / "libraries")) {
-			librarydir = boosty::stringy(tmpdir);
-		}
-
-	if (!librarydir.empty()) add_librarydir(librarydir);
+	add_librarydir(boosty::absolute(PlatformUtils::resourcePath("libraries")).string());
 }
